package io.github.beradq.adybubbles

import taboolib.common.LifeCycle
import taboolib.common.platform.Awake
import taboolib.module.configuration.Config
import taboolib.module.configuration.ConfigFile

object Config {
    @Config("config.yml")
    lateinit var configFile: ConfigFile
    lateinit var bubblesConfig: BubblesConfig

    class BubblesChatConfig(
        val period: Long,
        val limit: Int
    )

    class BubblesConfig(
        val offset: Double,
        val lineHeight: Double,
        val chat: BubblesChatConfig
    )

    @Awake(LifeCycle.ENABLE)
    fun reload() {
        configFile.reload()
        val offset = configFile["offset"] as? Double ?: 0.5
        val lineHeight = configFile["line-height"] as? Double ?: 0.5
        val chat = configFile.getConfigurationSection("chat")
        val period = chat?.get("period") as? Long ?: (20 * 3)
        val limit = chat?.get("limit") as? Int ?: 3
        bubblesConfig = BubblesConfig(offset, lineHeight, BubblesChatConfig(period, limit))
    }
}